@@ -158,7 +158,7 @@ static int get_mp3tags(PerlIO *infile, char *file, HV *info, HV *tags);
 static int get_mp3fileinfo(PerlIO *infile, char *file, HV *info);
 static int _decode_mp3_frame(unsigned char *frame, struct mp3_frameinfo *pfi);
 static int mp3_find_frame(PerlIO *infile, char *file, int offset);
-static int _has_ape(PerlIO *infile);
+static int _has_ape(PerlIO *infile, off_t file_size);
 
 // bitrate_tbl[layer_index][bitrate_index]
 static int bitrate_tbl[5][16] = {
